@@ -7,7 +7,7 @@ objects.
 def get_enrollment_object():
     """Backend to get enrollment object."""
     try:
-        from student.models import CourseEnrollment
+        from student.models import CourseEnrollment  # pylint: disable=import-outside-toplevel
     except ImportError:
         CourseEnrollment = object
     return CourseEnrollment
